# CS107/AC207 Final Project

#### Group Name: cs107-command-lies
#### Project Number: 29

#### Team:

| first name        | last name           | email  |
| ------------- |:-------------| :-----|
| Elizabeth      | Suitor | esuitor@g.harvard.edu |
| Lauryn | Wu | laurynwu@college.harvard.com |
| Emil | Ghitman Gilkes | emil_ghitmangilkes@g.harvard.edu |
| Robert | Roessler | robertroessler@g.harvard.edu |

[![Build Status](https://app.travis-ci.com/cs107-CommandLies/cs107-FinalProject.svg?token=PCytefEoEaifyEmDLt8H&branch=main)](https://app.travis-ci.com/cs107-CommandLies/cs107-FinalProject)

[![codecov](https://codecov.io/gh/cs107-CommandLies/cs107-FinalProject/branch/main/graph/badge.svg?token=7H4A0IZJD5)](https://codecov.io/gh/cs107-CommandLies/cs107-FinalProject)
